@@ -29,8 +29,8 @@ class Test(unittest.TestCase):
         self.assertEqual(pmf["l"], 2)
 
         pmf2 = pmf.copy()
-        self.assertEqual(len(pmf), 4)
-        self.assertEqual(pmf["l"], 2)
+        self.assertEqual(len(pmf2), 4)
+        self.assertEqual(pmf2["l"], 2)
 
         # test choice
         np.random.seed(42)
@@ -70,6 +70,18 @@ class Test(unittest.TestCase):
         pmf = Pmf.from_seq([3, 6, 1, 7, 2], sort=False)
         # self.assertEqual(pmf.qs[0], 1)
 
+        # check that we can deal with an unsorted Pmf
+        qs = [3, 1, 2, 4]
+        ps = [0.1, 0.2, 0.3, 0.4]
+        pmf = Pmf(ps, qs)
+        self.assertEqual(pmf.mean(), 2.7)
+
+        # when you make a Cdf, it gets sorted, because otherwise
+        # it's not a sensible Cdf
+        cdf = pmf.make_cdf()
+        self.assertEqual(cdf.quantile(0.3), 2)
+        self.assertEqual(cdf.quantile(0.6), 3)
+
     def testStats(self):
         pmf = Pmf.from_seq([1, 2, 3, 4, 5, 6])
         self.assertAlmostEqual(pmf.mean(), 3.5)
@@ -647,7 +659,9 @@ class Test(unittest.TestCase):
         self.assertListEqual(list(at_risk), [7.0, 6.0, 5.0, 3.0, 2.0, 1.0])
 
         haz = pmf_complete / at_risk
-        self.assertListEqual(list(haz), [0.14285714285714285, 0.0, 0.2, 0.0, 0.5, 0.0])
+        self.assertListEqual(
+            list(haz), [0.14285714285714285, 0.0, 0.2, 0.0, 0.5, 0.0]
+        )
 
     def almost_equal_dist(self, dist1, dist2):
         for x in dist1.qs:
